## $Id: export.py 17199 2022-12-01 14:37:50Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Exporters for applicant-related stuff.
"""
import grok
from waeup.kofa.applicants.interfaces import IApplicantBaseData
from waeup.kofa.utils.helpers import iface_names
from kofacustom.nigeria.applicants.export import NigeriaApplicantExporter
from kofacustom.lpng.applicants.interfaces import (
    ICustomApplicant, STATES, LGAS, WARDS, PUNITS)

class CustomApplicantExporter(NigeriaApplicantExporter):
    """Exporter for Custom Applicants.
    """

    fields = tuple(sorted(set(
        iface_names(ICustomApplicant) +
        iface_names(IApplicantBaseData)
        ))) + (
        'password', 'state', 'history', 'container_code', 'application_number',
        'display_fullname', 'application_date')

    def mangle_value(self, value, name, context=None):
        """The mangler determines the codes of the atributes `course1`,
        `course2` and `course_admitted`. It furthermore prepares the
        history messages and adds a hash symbol at the end of the phone number
        to avoid annoying automatic number transformation by Excel or Calc.
        """
        if name == 'federalstate':
            value = STATES.get(value, None)
        if name == 'lga':
            value = LGAS.get(value, None)
        if name == 'ward':
            value = WARDS.get(value, None)
        if name == 'punit':
            value = PUNITS.get(value, None)
        return super(
            CustomApplicantExporter, self).mangle_value(
            value, name, context=context)